@@ -4,7 +4,7 @@ use warnings;
 
 use Test::More;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our $time = CORE::time();
 
 my $pkg = __PACKAGE__;
@@ -18,7 +18,7 @@ sub import {
 	my ($class, %opts) = @_;
 	$time = $opts{time} if defined $opts{time};
 
-	*CORE::GLOBAL::time = sub {
+	*CORE::GLOBAL::time = sub() {
 		if (in_effect) {
 			$time;
 		} else {
@@ -26,9 +26,9 @@ sub import {
 		}
 	};
 
-	*CORE::GLOBAL::sleep = sub {
+	*CORE::GLOBAL::sleep = sub(;$) {
 		if (in_effect) {
-			my $sleep = shift;
+			my $sleep = shift || 1;
 			$time += $sleep;
 			note "sleep $sleep";
 		} else {
@@ -48,21 +48,33 @@ __END__
 
 =head1 NAME
 
-Test::Time - Override time() and sleep() core function for tests.
+Test::Time - Overrides the time() and sleep() core functions for testing
 
 =head1 SYNOPSIS
 
-  use Test::Time; # just use
+    use Test::Time;
 
-  time(); # fixed time
+    # Freeze time
+    my $now = time();
 
-  sleep 1; # increment internal time (return immediately)
-  time(); # incremented
+    # Increment internal time (returns immediately)
+    sleep 1;
+
+    # Return internal time incremented by 1
+    my $then = time();
 
 
 =head1 DESCRIPTION
 
-Test::Time is for tests around time. You just use this module and your tests are all "time safe".
+Test::Time can be used to test modules that deal with time. Once you C<use> this 
+module, all references to C<time> and C<sleep> will be internalized. You can set
+custom time by passing time => number after the C<use> statement:
+
+    use Test::Time time => 1;
+
+    my $now = time;    # $now is equal to 1
+    sleep 300;         # returns immediately, displaying a note
+    my $then = time;   # $then equals to 301
 
 =head1 AUTHOR
 
